oumi.models.experimental.cambrian.model.multimodal\_projector
=============================================================
.. py:module:: oumi.models.experimental.cambrian.model.multimodal_projector

Submodules
----------

oumi.models.experimental.cambrian.model.multimodal\_projector.builder module
----------------------------------------------------------------------------

.. automodule:: oumi.models.experimental.cambrian.model.multimodal_projector.builder
   :members:
   :undoc-members:
   :show-inheritance:

oumi.models.experimental.cambrian.model.multimodal\_projector.projectors module
-------------------------------------------------------------------------------

.. automodule:: oumi.models.experimental.cambrian.model.multimodal_projector.projectors
   :members:
   :undoc-members:
   :show-inheritance:
